@@ -8,7 +8,7 @@
 
 BEGIN { $| = 1; print "1..1\n"; }
 END {print "not ok 1\n" unless $loaded;}
-use DBI::Ima;
+use Ima::DBI;
 $loaded = 1;
 print "ok 1\n";
 
@@ -18,3 +18,11 @@ print "ok 1\n";
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
 
+
+
+
+
+
+
+
+
